@@ -394,8 +394,6 @@ class _BasePythonVirtualenvOperator(PythonOperator, metaclass=ABCMeta):
         "prev_execution_date",
         "prev_execution_date_success",
     }
-    if AIRFLOW_V_3_0_PLUS:
-        PENDULUM_SERIALIZABLE_CONTEXT_KEYS.add("start_date")
 
     AIRFLOW_SERIALIZABLE_CONTEXT_KEYS = {
         "macros",
@@ -793,7 +791,7 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
                     if hash_marker.exists():
                         previous_hash_data = hash_marker.read_text(encoding="utf8")
                         if previous_hash_data == hash_data:
-                            self.log.info("Re-using cached Python virtual environment in %s", venv_path)
+                            self.log.info("Reusing cached Python virtual environment in %s", venv_path)
                             return venv_path
 
                         _, hash_data_before_upgrade = self._calculate_cache_hash(exclude_cloudpickle=True)
